VisionGallerySaver class

VisionGallerySaver: A powerful tool for saving media to your device's gallery, inspired by Vision's ability to process and store digital information.

Constructors

VisionGallerySaver()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
Get the platform version
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

saveFile(String file, {String? name, bool isReturnPathOfIOS = false, bool skipIfExists = false, String? androidRelativePath}) Future<Map<String, dynamic>>
Save file to gallery with Vision's efficiency file The path to your digital asset name optional: The designation for the file isReturnPathOfIOS whether to return the file coordinates for iOS skipIfExists optional: Skip saving if file with same name already exists androidRelativePath optional: Custom subfolder path in gallery (Android only)
saveImage(Uint8List imageBytes, {int quality = 80, String? name, bool isReturnImagePathOfIOS = false, bool skipIfExists = false, String? androidRelativePath}) Future<Map<String, dynamic>>
Save image to gallery with Vision's precision imageBytes required: The digital essence of the image (bytes) quality optional: The clarity level (1-100) name optional: The designation for the image isReturnImagePathOfIOS whether to return the image coordinates for iOS skipIfExists optional: Skip saving if file with same name already exists androidRelativePath optional: Custom subfolder path in gallery (Android only)